"""
Model for generated file representation.

This model represents a file that will be generated by the
multi-document model generator.
"""

from pathlib import Path

from pydantic import BaseModel, Field


class ModelGeneratedFile(BaseModel):
    """Represents a generated file."""

    path: Path = Field(default=..., description="Path where the file will be written")
    content: str = Field(default=..., description="Content of the file")
    file_type: str = Field(
        default=...,
        description="Type of file (models, config, error_codes, etc.)",
    )
