"""Error models for ONEX framework."""

from omnibase_core.models.errors.model_fail_fast_details import ModelFailFastDetails
from omnibase_core.models.errors.model_onex_error import ModelOnexError

__all__ = [
    "ModelFailFastDetails",
    "ModelOnexError",
]
