"""Validation contracts for ONEX validators.

This package contains YAML contract definitions for validators
that use the contract-driven validation framework.

Available contracts (YAML files):
- any_type.validation.yaml
- architecture.validation.yaml
- contract_linter.validation.yaml
- naming_convention.validation.yaml
- patterns.validation.yaml
- union_usage.validation.yaml
"""

# No Python modules to export; this package contains only YAML contract files
__all__: list[str] = []
